package images;

import java.awt.*;
import java.io.*;
import java.util.*;
import javax.swing.*;
import java.awt.event.*;
import javax.swing.filechooser.FileFilter;

public class ImageFrame extends JFrame
{
  // lments du menu
  private JMenuBar menuBar = new JMenuBar();
  private JMenu menuFichier = new JMenu();
  private JMenu menuCharger = new JMenu();
  private JMenuItem menuFichierSelection = new JMenuItem();
  private JMenuItem menuFichierQuitter = new JMenuItem();
  private JMenuItem menuFichierEnregistrer = new JMenuItem();

  private BorderLayout layoutMain = new BorderLayout();

  // lments de slection de fichiers
  private FileFilter fileFilter = null;
  private FileFilter datFilter = null;
  private JFileChooser fileChooser = new JFileChooser("."); // dmarrage dans le rpertoire courant
  private JFileChooser bddChooser = new JFileChooser(".");

  // membre permettant de grer l'interaction avec la base de donnes
  private Bdd gestionBdd = null;

  public ImageFrame()
  {
    try
    {
      jbInit();
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }
  }

  private void jbInit() throws Exception
  {
    this.setJMenuBar(menuBar);
    this.getContentPane().setLayout(layoutMain);
    this.setTitle("Gestionnaire d'images");
    this.setBackground(SystemColor.control);

    // gestion de la fermeture
    this.addWindowListener(new WindowAdapter()
      {
        public void windowClosing(WindowEvent e)
        {
          quitter();
        }
      });

    // initialisation des filtres pour les diffrentes slections
    String[] filters = new String[]{"jpg","bmp","gif"};
    fileFilter = new ExtensionFileFilter("images",filters);
    fileChooser.addChoosableFileFilter(fileFilter);

    datFilter = new ExtensionFileFilter("proprit bdd","dat");
    bddChooser.addChoosableFileFilter(datFilter);

    // gestion des diffrents lments du menu

    menuFichier.setText("Fichier");
    menuFichierSelection.setText("Selectionner la base");
    menuFichierEnregistrer.setText("Enregistrer dans la bdd");
	menuFichierEnregistrer.setEnabled(false);
    menuCharger.setText("Charger");
    menuFichierQuitter.setText("Quitter");

    menuFichierSelection.addActionListener(new ActionListener()
      {
        public void actionPerformed(ActionEvent e)
        {
          int status = bddChooser.showDialog(null,"Slection du fichier de configuration de la base");

          if(status == JFileChooser.APPROVE_OPTION)
          {
            File file = bddChooser.getSelectedFile();
            menuFichierEnregistrer.setEnabled(false);
            try
            {
              gestionBdd.deconnexion();
              gestionBdd.initialiserConnexion(file.getAbsolutePath());
              initMenuCharger(); // on rcupre les noms des images prsentes en base
              menuFichierEnregistrer.setEnabled(true);
            }
            catch(Exception ex)
            {
              JOptionPane.showMessageDialog(null,"Une erreur s'est produite dans l'initialisation de la connexion");
              menuCharger.removeAll(); // on supprime les lment du menu Charger
              ex.printStackTrace();
            }
          }
        }
      }
    );

    menuFichierEnregistrer.addActionListener(new ActionListener()
      {
        public void actionPerformed(ActionEvent e)
        {
          int status = fileChooser.showDialog(null,"Slection du fichier  sauver");

          if(status == JFileChooser.APPROVE_OPTION)
          {
            File file = fileChooser.getSelectedFile();
            String name;
            String message = "Quel nom donner  ce fichier en base ?";
            name = JOptionPane.showInputDialog(message);
            if(name != null)
            {
              try
              {
                gestionBdd.sauveIMG(file.getAbsolutePath(),name);
                initMenuCharger(); // on recharge la liste des images
              }
              catch(Exception ex)
              {
                JOptionPane.showMessageDialog(null,"Une erreur s'est produite dans l'enregistrement de l'image.");
                ex.printStackTrace();
              }
            }
          }
        }
      });

    menuFichierQuitter.addActionListener(new ActionListener()
      {
        public void actionPerformed(ActionEvent ae)
        {
          quitter();
        }
      });

    menuFichier.add(menuFichierSelection);
    menuFichier.add(menuFichierEnregistrer);
    menuFichier.add(menuFichierQuitter);
    menuBar.add(menuFichier);
    menuBar.add(menuCharger);

  }

  private void initMenuCharger()
  {
    try
    {
      Vector v = new Vector(gestionBdd.getAllNames());
      Iterator it = v.iterator();
      menuCharger.removeAll(); // on supprime les lment du menu Charger
      while(it.hasNext())
      {
      /* cration dynamique des lments du menu charger
      avec cration d'un listener. */
        final String name = (String) it.next();
        JMenuItem item = new JMenuItem(name);
        item.addActionListener(new ActionListener()
          {
            public void actionPerformed(ActionEvent e)
            {
              int status = fileChooser.showDialog(null,"Saisir l'emplacement et le nom du fichier cible");

              if(status == JFileChooser.APPROVE_OPTION)
              {
                try
                {
                  gestionBdd.chargeIMG(name,fileChooser.getSelectedFile().getAbsolutePath());
                }
                catch(Exception ex)
                {
                  JOptionPane.showMessageDialog(null,"Une erreur s'est produite dans le chargement de l'image.");
                  ex.printStackTrace();
                }
              }
            }
          }
        );

        menuCharger.add(item); // on ajoute l'lment dans le menu
      }
    }
    catch(Exception ex)
    {
      JOptionPane.showMessageDialog(null,"Une erreur s'est produite lors de la rcupration des noms d'image.");
      ex.printStackTrace();
    }
  }

  // permet de dfinir le gestionnaire de base de donnes
  public void setGestionnaireBdd(Bdd bdd)
  {
    this.gestionBdd = bdd;
  }

  public void quitter()
  {
    try
    {
      gestionBdd.deconnexion();
    }
    catch(Exception ex)
    {
      JOptionPane.showMessageDialog(null,"Une erreur s'est produite lors de la dconnexion.");
      ex.printStackTrace();
    }
    System.exit(0);
  }

  public static void main(String[] args)
  {
    ImageFrame f = new ImageFrame();
    f.setSize(300,300);
    Bdd gestionnaireBdd = new Bdd();
    f.setGestionnaireBdd(gestionnaireBdd);
    f.show();
  }
}